from omu_chat.model import Author, Channel, Message, Provider, Room, Vote

from .event import TableEvent


class events:
    message = TableEvent[Message](lambda chat: chat.messages)
    author = TableEvent[Author](lambda chat: chat.authors)
    channel = TableEvent[Channel](lambda chat: chat.channels)
    provider = TableEvent[Provider](lambda chat: chat.providers)
    room = TableEvent[Room](lambda chat: chat.rooms)
    vote = TableEvent[Vote](lambda chat: chat.votes)



from . import permissions
from .chat import Chat
from .event.event_types import events
from .model import (
    Author,
    Channel,
    Gift,
    Message,
    Paid,
    Provider,
    Role,
    Room,
    content,
)
from .version import VERSION

__version__ = VERSION
__all__ = [
    "permissions",
    "Chat",
    "Author",
    "Channel",
    "content",
    "events",
    "Gift",
    "Message",
    "Paid",
    "Provider",
    "Role",
    "Room",
]
